import { NextResponse } from 'next/server';

export async function GET() {
  const apiKey = process.env.CAIYUN_API_KEY;
  // 请替换为你的实际坐标（示例使用北京坐标）
  const [longitude, latitude] = [116.3974, 39.9093];
  
  try {
    // 同时获取实时天气和6天预报
    const [realtimeRes, dailyRes] = await Promise.all([
      fetch(`https://api.caiyunapp.com/v2.6/${apiKey}/${longitude},${latitude}/realtime`),
      fetch(`https://api.caiyunapp.com/v2.6/${apiKey}/${longitude},${latitude}/daily?dailysteps=6`)
    ]);

    // 检查响应状态
    if (!realtimeRes.ok || !dailyRes.ok) {
      throw new Error('API请求失败');
    }

    const realtimeData = await realtimeRes.json();
    const dailyData = await dailyRes.json();

    // 检查API返回状态
    if (realtimeData.status !== 'ok' || dailyData.status !== 'ok') {
      throw new Error('天气数据异常');
    }

    // 数据格式转换
    const formattedData = {
      temp: Math.round(realtimeData.result.realtime.temperature),
      feelsLike: Math.round(realtimeData.result.realtime.apparent_temperature),
      condition: translateSkycon(realtimeData.result.realtime.skycon),
      windSpeed: realtimeData.result.realtime.wind.speed.toFixed(1),
      windDirection: getWindDirection(realtimeData.result.realtime.wind.direction),
      uvIndex: realtimeData.result.realtime.life_index.ultraviolet.desc,
      forecast: dailyData.result.daily.temperature.slice(0, 6).map((item: any, index: number) => ({
        day: formatDailyDate(item.date),
        low: Math.round(item.min),
        high: Math.round(item.max),
        condition: translateSkycon(dailyData.result.daily.skycon[index]?.value)
      }))
    };

    return NextResponse.json(formattedData, {
      headers: {
        'Cache-Control': 'public, s-maxage=600', // 缓存10分钟
        'CDN-Cache-Control': 'public, s-maxage=1800' // CDN缓存30分钟
      }
    });
  } catch (error) {
    console.error('天气获取失败:', error);
    return NextResponse.json(
      { error: "天气数据获取失败" },
      { status: 500 }
    );
  }
}

// 天气状况翻译（根据最新文档更新）
function translateSkycon(skycon: string) {
  const skyconMap: Record<string, string> = {
    "CLEAR_DAY": "晴",
    "CLEAR_NIGHT": "晴",
    "PARTLY_CLOUDY_DAY": "多云",
    "PARTLY_CLOUDY_NIGHT": "多云",
    "CLOUDY": "阴",
    "LIGHT_RAIN": "小雨",
    "MODERATE_RAIN": "中雨",
    "HEAVY_RAIN": "大雨",
    "STORM_RAIN": "暴雨",
    "FOG": "雾",
    "LIGHT_SNOW": "小雪",
    "MODERATE_SNOW": "中雪",
    "HEAVY_SNOW": "大雪",
    "STORM_SNOW": "暴雪",
    "DUST": "浮尘",
    "SAND": "沙尘",
    "WIND": "大风"
  };
  return skyconMap[skycon] || "未知天气";
}

// 风向转换（根据官方文档说明）
function getWindDirection(degree: number) {
  const directions = ["北风", "东北风", "东风", "东南风", "南风", "西南风", "西风", "西北风"];
  return directions[Math.floor((degree + 22.5) % 360 / 45)] || "未知风向";
}

// 日期格式化（显示星期）
function formatDailyDate(dateStr: string) {
  try {
    const date = new Date(dateStr);
    const weekdays = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"];
    return weekdays[date.getDay()];
  } catch {
    return "未知日期";
  }
}