// src/components/NewsSection.tsx
"use client";

import { FC, useState, useEffect } from "react";
import { NewsItem } from "../types/magic-mirror";

const SCROLL_INTERVAL = 8000;

const NewsSection: FC<{ items: NewsItem[] }> = ({ items }) => {
  const [activeIndex, setActiveIndex] = useState(0);
  const [isHovered, setIsHovered] = useState(false);

  useEffect(() => {
    if (items.length <= 1) return;
    
    const timer = setInterval(() => {
      if (!isHovered) setActiveIndex(prev => (prev + 1) % items.length);
    }, SCROLL_INTERVAL);
    
    return () => clearInterval(timer);
  }, [items.length, isHovered]);

  if (items.length === 0) {
    return (
      <div className="fixed bottom-8 left-1/2 -translate-x-1/2 w-[800px] h-20 flex items-center justify-center">
        <div className="text-gray-400 text-sm">正在加载最新新闻...</div>
      </div>
    );
  }

  return (
    <div 
      className="fixed bottom-8 left-1/2 -translate-x-1/2 w-[800px] h-20 overflow-hidden"
      onMouseEnter={() => setIsHovered(true)}
      onMouseLeave={() => setIsHovered(false)}
    >
      <div className="relative h-full">
        {items.map((item, index) => (
          <div
            key={item.uniquekey}
            className="absolute inset-0 transition-all duration-500 ease-[cubic-bezier(0.4,0,0.2,1)]"
            style={{
              transform: `translateY(${(index - activeIndex) * 100}%)`,
              opacity: index === activeIndex ? 1 : 0,
              pointerEvents: index === activeIndex ? 'auto' : 'none'
            }}
          >
            <a
              href={item.url}
              target="_blank"
              rel="noopener noreferrer"
              className="h-full px-6 flex flex-col justify-center items-center text-center hover:bg-white/5 transition-colors group space-y-1.5"
            >
              {/* 信息行 - 添加时间显示 */}
              <div className="flex items-center text-gray-400/80 text-sm space-x-2">
                <span>{formatNewsDate(item.date)}</span>
                <span className="text-gray-500">·</span>
                <span>{formatNewsTime(item.date)}</span>
                <span className="text-gray-500">·</span>
                <span>{item.category}</span>
                {item.author_name && (
                  <>
                    <span className="text-gray-500">·</span>
                    <span>{item.author_name}</span>
                  </>
                )}
              </div>
              
              {/* 标题行 - 添加最大宽度限制 */}
              <div className="text-gray-300 text-xl font-medium tracking-wide group-hover:text-white transition-colors max-w-[90%]">
                {item.title}
              </div>
            </a>
          </div>
        ))}
      </div>
    </div>
  );
};

// 更新日期时间格式化函数
const formatNewsDate = (datetime?: string) => {
  if (!datetime) return "";
  const [datePart, timePart] = datetime.split(" ");
  const [year, month, day] = datePart.split("-");
  return `${parseInt(month)}月${parseInt(day)}日`;
};

const formatNewsTime = (datetime?: string) => {
  if (!datetime) return "";
  const timePart = datetime.split(" ")[1] || "";
  const [hours, minutes] = timePart.split(":");
  return `${hours}时${minutes}分`;
};

export default NewsSection;